Autenticação Mecânica / Ficha de Compensação Código de baixa Pagador / Avalista Pagador Client Mainstreet 138, Cidade Araci 12345-678 - Los Angeles - Californa (=) Valor cobrado (+) Outros acréscimos (+) Mora/Multa (-) Outras deduções (-) Descontos/Abatimentos Instruções Primeia linha da instrução Uso do banco Carteira Espécie Quantidade Valor (=) Valor documento R$ 10,00 Data do documento N. do documento Espécie doc Aceite Data processamento Nosso número 30/05/2011 00400 DM N 30/05/2011 8000000400 Beneficiário Agência/Código Beneficiário Moda Stoq 1565/00000000414-3 Local de pagamento Vencimento Pagável em qualquer banco até o vencimento 30/05/2011 104-0 10498.00004 00400.156501 00000.004143 2 49830000001000 104-0 Recibo do Pagador Autenticação Mecânica Beneficiário Agência/Código Beneficiário Data Documento Vencimento Endereço Beneficiário CNPJ Beneficiário Pagador Nosso Número N. do documento Valor Documento Demonstrativo Moda Stoq 1565/00000000414-3 30/05/2011 30/05/2011 Avendia São Carlos 2333, Centro, 13560-001 - São Carlos - SP 24.198.774/7322-35 Client 8000000400 00400 10,00 Sale 00123 - Description